@@ -21,10 +21,27 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 # Imports (wildcard)
+from .data import *
+from .distributed import *
 from .logging import *
 from .nn import *
 from .optim import *
 
+# Deletions (from .data)
+del FastCollateMixup
+del Mixup
+del cifarhundred_dataloader_dispatcher
+del cifarten_dataloader_dispatcher
+del fashionmnist_dataloader_dispatcher
+del imagenette_dataloader_dispatcher
+del mnist_dataloader_dispatcher
+del data_prep_dispatcher_1ch
+del data_prep_dispatcher_3ch
+
+# Deletions (from .distributed)
+del slurm_nccl_env
+del reduce_accumulate_keepalive
+
 # Deletions (from .nn)
 del ArgMaxLayer
 del BatchNorm2dRP
@@ -42,28 +59,27 @@ del FCBlockLegacy
 del FieldTransform
 del FlatChannelize2DLayer
 del GaussianReparameterizerSampler
+del InnerProduct
 del KWTA1d
 del KWTA2d
-del LMUCell
 del Mish
-del MishPulse
-del MishPulseSymmY
 del MultiSolvePoissonTensor
 del NNEnsemble
 del PoissonNetCifar
 del ProbePrintLayer
 del ReshapeLayer
+del ScaledERF
 del SERLU
 del SGRUHCell
 del SinLU
 del SmeLU
 del SolvePoisson
 del SolvePoissonTensor
+del WideResNet
+del PreActResNet
 del beta_reco_bce
 del field_transform
 del mishlayer_init
-del mishpulse
-del mishpulse_symmy
 del patch_rp_train_network
 del pixelwise_bce_mean
 del pixelwise_bce_sum
@@ -72,10 +88,18 @@ del pixelwise_bce_sum
 del AdaHessian
 del Adan
 del Lion
+del AutoWU
 del Lookahead
+del Lookaround
 del RAdam
 del SAM
+del AdaBound
 del ralah_optim
+del wfneal
+del tricyc1c
+del epochwise_onecycle
+del onecycle_lincos
+del onecycle_linlin
 
 # Deletions (from .logging)
 del AverageMeter
