@@ -1,25 +1,16 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-# ==============================================================================
+# ------------------------------------------------------------------------------
 #
-# Copyright 2020-* Emanuele Ballarin <emanuele@ballarin.cc>
-# All Rights Reserved. Unless otherwise explicitly stated.
+#  Copyright (c) 2020-2023 Emanuele Ballarin <emanuele@ballarin.cc>
+#  Released under the terms of the MIT License
+#  (see: https://url.ballarin.cc/mitlicense)
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# ------------------------------------------------------------------------------
 #
-#     https://www.apache.org/licenses/LICENSE-2.0
+# SPDX-License-Identifier: MIT
 #
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-#
-# ==============================================================================
-#
-# SPDX-License-Identifier: Apache-2.0
+# ------------------------------------------------------------------------------
 # Imports
 from .architectures import ArgMaxLayer
 from .architectures import beta_reco_bce
@@ -28,9 +19,12 @@ from .architectures import CausalConv1d
 from .architectures import FCBlock
 from .architectures import FCBlockLegacy
 from .architectures import GaussianReparameterizerSampler
+from .architectures import InnerProduct
 from .architectures import pixelwise_bce_mean
 from .architectures import pixelwise_bce_sum
 from .architectures import SGRUHCell
+from .architectures_resnets_dm import PreActResNet
+from .architectures_resnets_dm import WideResNet
 from .conv2drp import BatchNorm2dRP
 from .conv2drp import Conv2dRP
 from .conv2drp import Dropout2dRP
@@ -43,8 +37,6 @@ from .debuglayers import ProbePrintLayer
 from .fieldtransform import FieldTransform
 from .functional import field_transform
 from .functional import mish
-from .functional import mishpulse
-from .functional import mishpulse_symmy
 from .kwta import BrokenReLU
 from .kwta import KWTA1d
 from .kwta import KWTA2d
@@ -52,14 +44,12 @@ from .laplacenet import MultiSolvePoissonTensor
 from .laplacenet import PoissonNetCifar
 from .laplacenet import SolvePoisson
 from .laplacenet import SolvePoissonTensor
-from .lmu import LMUCell
 from .mish import Mish
 from .mish import mishlayer_init
-from .mish import MishPulse
-from .mish import MishPulseSymmY
 from .nnsemble import NNEnsemble
 from .reshapelayers import FlatChannelize2DLayer
 from .reshapelayers import ReshapeLayer
+from .serf import ScaledERF
 from .serlu import SERLU
 from .sinlu import SinLU
 from .smelu import SmeLU
@@ -67,6 +57,7 @@ from .utils import *
 
 # Deletions (from .)
 del architectures
+del architectures_resnets_dm
 del conv2drp
 del convolutional_flatten
 del coordconv
@@ -74,16 +65,17 @@ del debuglayers
 del fieldtransform
 del kwta
 del laplacenet
-del lmu
 del mish
 del nnsemble
 del reshapelayers
 del serlu
 del sinlu
 del smelu
+del serf
 
 # Deletions (from .functional)
 # del mish  # (already done by chance!)
+# del serf  # (already done by chance!)
 
 # Deletions (from .utils)
 del AdverApply
