@@ -21,11 +21,19 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 # Imports (specific)
+from .adabound import AdaBound
 from .adahessian import AdaHessian
 from .adan import Adan
+from .autowu import AutoWU
+from .custom import epochwise_onecycle
+from .custom import onecycle_lincos
+from .custom import onecycle_linlin
 from .custom import ralah_optim
+from .custom import tricyc1c
+from .custom import wfneal
 from .lion import Lion
 from .lookahead import Lookahead
+from .lookaround import Lookaround
 from .radam import RAdam
 from .sam import SAM
 
@@ -34,6 +42,9 @@ del adahessian
 del adan
 del custom
 del lion
+del autowu
 del lookahead
+del lookaround
 del radam
 del sam
+del adabound
